==> tanker-cli-0.0.1.tgz: package/bin/index.js <==
const os = require('os');
const path = require('path');
const fs = require('fs-extra');
const axios = require('axios');
const { spawn } = require('child_process');
const { program } = require('commander');
const { prompt, Select, Toggle } = require('enquirer');
const package = require('../package.json');
const dest = path.join(process.env.HOME, '.tanker');

const content = fs.readJsonSync(dest);
const instance = axios.create({
  baseURL: content.api,
  timeout: content.timeout,
  headers: {'Authorization': `Bearer ${content.token}`}
});

// const api = `https://0.0.0.0:8080/api/`;
const api = `https://tanker.xarlike.info/api/`;
const timeout = 1000;

program
  .command('configure')
  .description('Set token to access your tanker\'s scripts')
  .action(async function () {
    const token = await prompt({
      type: 'input',
      name: 'token',
      message: 'What is your token ?'
    });

    const state = Object.assign({}, token, { api, timeout });
    fs.writeJsonSync(dest, state);
    console.log("Ready.");
  });

program
  .command('reset')
  .description('Unset your token')
  .action(async function () {

    const prompt = new Toggle({
      message: 'Do you can to remove your access token ?',
      enabled: 'Yes',
      disabled: 'No'
    });

    prompt.run()
      .then(answer => {
        answer && fs.writeJsonSync(dest, { })
      })
      .catch(console.error);
  });

program
  .command('use')
  .description('Choose a script')
  .action(async function () {
    try {
      const { data } = await instance.get("/codes");

      const choices = data.map((el) => {
        return { name: el.title, value: el.id };
      });

      const prompt = new Select({
        message: 'Which script do you want to select ?',
        choices,
        result(names) {
         return this.map(names);
        }
      });

      prompt.run()
        .then(res => {
          const keys = Object.keys(res);
          keys.forEach(async (key) => {
            const codeId = res[key];
            const { data } = await instance.get(`/codes/${codeId}`);
            const state = Object.assign({}, content, { payload: data });
            fs.writeJsonSync(dest, state)
          });
        })
        .catch(console.error);
    } catch (e) {
      if (e?.response?.status === 401) {
          console.error("401 Unauthorized");
          return console.error('Need to run this command "tanker configure" first');
      }
      return console.error("Server error 500");
    }
  });

program
  .command('run')
  .description('Run selected script')
  .action(async function () {
    const once = [...Array(12)].map(i=>(~~(Math.random()*36)).toString(36)).join('');
    const fileName = path.join(os.tmpdir(), `payload-${once}.sh`);
    // console.log(fileName);
    try {
      if (content?.payload?.content) {
        fs.writeFileSync(fileName, content.payload.content, { mode: 0o700 });
      } else {
        return console.error('Need to run this command "tanker use" first');
      }

      const copy = [...process.argv];
      while (copy.shift() !== "run") {}
      copy.unshift(fileName);

      const bat = spawn('bash', copy);
      bat.stdout.on('data', (data) => {
        process.stdout.write(data.toString());
      });
      bat.stderr.on('data', (data) => {
        process.stderr.write(data.toString());
      });
    } catch (e) {
      return console.error(e);
    }
  });

program
  .command('status')
  .action(function () {
    if (content.token && content.token.length) {
      console.log('token:', content.token);
      if (content?.payload?.content) {
        console.log('current:', content.payload.title);
      }
    } else {
      console.log('Need to run this command "tanker configure" first');
    }
  });

program.parse(process.argv)

==> tanker-cli-0.0.3.tgz: package/bin/index.js <==
#!/usr/bin/env node

const os = require('os');
const path = require('path');
const fs = require('fs-extra');
const axios = require('axios');
const { spawn } = require('child_process');
const { program } = require('commander');
const { prompt, Select, Toggle } = require('enquirer');

const package = require('../package.json');
const dest = path.join(process.env.HOME, '.tanker');
const content = fs.readJsonSync(dest, { throws: false });

let instance = null;
if  (content) {
  instance = axios.create({
    baseURL: content.api,
    timeout: content.timeout,
    headers: { 'Authorization': `Bearer ${content.token}` }
  });
}

program
  .command('configure')
  .description('Set token to access your tanker\'s scripts')
  .action(async function () {
    const api = `https://tanker.xarlike.info/api/`;
    const timeout = 1000;
    const token = await prompt({
      type: 'input',
      name: 'token',
      message: 'What is your token ?'
    });

    const state = Object.assign({}, token, { api, timeout });
    fs.writeJsonSync(dest, state);
    console.log("Ready.");
  });

program
  .command('reset')
  .description('Unset your token')
  .action(async function () {

    if (content === null) {
      return console.error('There is no configuration to delete.');
    }

    const prompt = new Toggle({
      message: 'Do you can to remove your access token ?',
      enabled: 'Yes',
      disabled: 'No'
    });

    prompt.run()
      .then(answer => {
        answer && fs.writeJsonSync(dest, { })
      })
      .catch(console.error);

  });

program
  .command('use')
  .description('Choose a script')
  .action(async function () {
    try {
      const { data } = await instance.get("/codes");

      const choices = data.map((el) => {
        return { name: el.title, value: el.id };
      });

      if (choices.length === 0) {
        return console.error('Nothing found');
      }

      const prompt = new Select({
        message: 'Which script do you want to select ?',
        choices,
        result(names) {
         return this.map(names);
        }
      });

      prompt.run()
        .then(res => {
          const keys = Object.keys(res);
          keys.forEach(async (key) => {
            const codeId = res[key];
            const { data } = await instance.get(`/codes/${codeId}`);
            const state = Object.assign({}, content, { payload: data });
            fs.writeJsonSync(dest, state)
          });
        })
        .catch(console.error);
    } catch (e) {
      if (e?.response?.status === 401) {
        console.error("401 - Unauthorized");
        return console.error('Need to run this command "tanker configure" first');
      }
      if (content === null) {
        console.error('Need to run this command "tanker configure" first');
      } else {
        console.error("Server error 500");
      }
    }
  });

program
  .command('run')
  .description('Run selected script')
  .action(async function () {
    const once = [...Array(12)].map(i=>(~~(Math.random()*36)).toString(36)).join('');
    const fileName = path.join(os.tmpdir(), `payload-${once}.sh`);

    try {
      if (content === null) {
        return console.error('Need to run this command "tanker configure" first');
      }

      if (content?.payload?.content) {
        fs.writeFileSync(fileName, content.payload.content, { mode: 0o500 });
      } else {
        return console.error('Need to run this command "tanker use" first');
      }

      const copy = [...process.argv];
      while (copy.shift() !== "run") {}
      copy.unshift(fileName);

      const bat = spawn('bash', copy);
      bat.stdout.on('data', (data) => {
        process.stdout.write(data.toString());
      });
      bat.stderr.on('data', (data) => {
        process.stderr.write(data.toString());
      });
    } catch (e) {
      return console.error(e);
    }
  });

program
  .command('status')
  .action(function () {
    if (content?.token && content?.token.length) {
      console.log('token:', content.token);
      if (content?.payload?.content) {
        console.log('current:', content.payload.title);
      }
    } else {
      console.log('Need to run this command "tanker configure" first');
    }
  });

program.parse(process.argv)
